@@ -143,6 +143,7 @@ def gdalwarp(filelist,
         gdal.Warp(filetmp, filelist_tmp, **kwargs)
         print("[GDALWARP] gdalwarp completed successfully")
         print("[GDALWARP] but fileprj:", os.path.exists(forceext(filetmp, "prj")))
+
     except Exception as ex:
         print("[GDALWARP]",ex)
     finally:
@@ -164,9 +165,9 @@ def gdalwarp(filelist,
         pass
 
     # moving the filetmp to fileout
-    print("[GDALWARP] moved filetmp to fileout:", os.path.exists(forceext(filetmp,"prj")))
+    print("[GDALWARP]filetmp:", forceext(filetmp,"prj"),  os.path.isfile(forceext(filetmp,"prj")))
     move(filetmp, fileout)
-    print("[GDALWARP] moved filetmp to fileout:", os.path.exists(forceext(fileout,"prj")))
+    print("[GDALWARP] moved filetmp to fileout:",fileout, os.path.isfile(forceext(fileout,"prj")))
 
     Logger.debug("gdalwarp: converted to %s in %.2fs.",
                  fileout, total_seconds_from(t0))
